salemove_http_client v1.0.1 Salemove.HttpClient.Decoder
A module, responsible for creating a EngagementRouter.HttpClient.Response
from Tesla response, or, if request wasn't successful, for creating one
of exception structures.
Link to this section Summary
Functions
Accepts result of request to Tesla client and constructs
Elixir.Salemove.HttpClient.Response structure from it.
Link to this section Types
Link to this type
on_decode()
on_decode() :: {:ok, Salemove.HttpClient.Response.t()} | {:error, reason()}
Link to this type
reason()
reason() :: Salemove.HttpClient.JSONError.t() | Salemove.HttpClient.ConnectionError.t() | Salemove.HttpClient.UnexpectedRedirectError.t() | Salemove.HttpClient.ClientError.t() | Salemove.HttpClient.ServerError.t() | Salemove.HttpClient.UnavailableError.t() | Salemove.HttpClient.UnsupportedProtocolError.t()
Link to this section Functions
Accepts result of request to Tesla client and constructs
Elixir.Salemove.HttpClient.Response structure from it.